from django.forms import Form

from .jsonschema import JSONSchema


class JSONSchemaFormMixin:
    """Mixin to extend Django forms with a converter into a JSON schema."""
    layout = None

    def as_jsonschema(self: Form) -> dict:
        """Encode form fields and layout into a JSON schema."""
        schema = JSONSchema()

        if self.layout is None:
            # If no layout is provided, simply add all fields as individual rows
            for name, field in self.fields.items():
                schema.add_field(name, field)
        else:
            # Offload generation to the layout class
            schema.update_properties(self.layout.build_schema(schema, self.fields)["properties"])

        return schema.schema
